# /etc/csh.cshrc

# It is recommended that this file be left unchanged to permit for upgrades,
# and any local additions go into /etc/profile.d/local.csh (if enabled) and
# (preferrably) ~/.tcshrc

# set $SHELL to the actual name
if ($?tcsh) then
  setenv SHELL `which tcsh`
endif

limit coredumpsize 0
umask 077

setenv HOSTNAME `hostname -f`

test -f $HOME/.inputrc || setenv INPUTRC /etc/inputrc

# Some locales (e.g. Russian) use comma instead of decimal dot - that could
# be dangerous, and we prefer to avoid that; all other locale parameters are
# normally set in $LANG (e.g. `setenv LANG ru_RU.UTF-8` in ~/.tcshrc)
setenv LC_NUMERIC "C"

# Normally /opt is a symlink to /usr/local, but just in case
setenv PATH "/bin:/usr/bin:/opt/bin:/usr/local/bin:/sbin:/usr/sbin:/opt/sbin:/usr/local/sbin"

# Besides just looking good, this prompt syntax allows copying it to command
# line of programs like rsync and scp
set prompt='%n@%m:%~ %# '

# Additionally mark the root prompt; color sequences require a TTY
if ($?prompt && "$uid" == 0) then
  set prompt="%{\033[33;41;1m%}%n@%m%{\033[0m%}:%~ %# "
endif

# Uncomment to enable parsing /etc/profile.d/*.csh
#set enable_profile_d

set autolist=ambiguous
set ellipsis
set globstar
set history=1024
set histdup=erase
set nonomatch
unset autologout
unset savehist

# Almost perfect for the lightgrey-on-black termminals
#setenv LS_COLORS 'rs=0:di=01;36:ln=target:mh=00:bd=31:cd=35:pi=33:so=01;30:or=40;31;01:su=01;33;41:sg=01;31;43:ca=30;41:tw=01;30;46:ow=01;36;41:st=37;44:ex=32'

alias ls 'ls-F --group-directories-first --color=tty -Ca'
alias lh 'ls-F --group-directories-first --color=tty -lha'
alias ll 'ls-F --group-directories-first --color=tty -la'
alias psg 'ps wax | grep -v grep | egrep -i'
alias psl 'ps wax | less'

# Do you know anyone who really uses these aliases?
unalias d
unalias dir
unalias v
unalias vdir

if ($?prompt) then
  complete cd 'p/1/d/'
  complete exec 'p/1/c/'
  complete which 'n/*/c/'
endif

if ( $?enable_profile_d && -d /etc/profile.d ) then
  foreach i ( /etc/profile.d/*.csh )
    test -f "$i" && source $i
  end
  unset i
endif
